pub fn use_scroll_controller(
init: impl FnOnce() -> ScrollConfig,
) -> ScrollControllerExpand description
Creates a ScrollController tied to the component, configured by the returned ScrollConfig.
pub fn use_scroll_controller(
init: impl FnOnce() -> ScrollConfig,
) -> ScrollControllerCreates a ScrollController tied to the component, configured by the returned ScrollConfig.